@@ -1,9 +1,8 @@
-
 /***************************************************************************
  *  AudioCdDisk.cs
  *
- *  Copyright (C) 2005 Novell
- *  Written by Aaron Bockover (aaron@aaronbock.net)
+ *  Copyright (C) 2005-2006 Novell, Inc.
+ *  Written by Aaron Bockover <aaron@abock.org>
  ****************************************************************************/
 
 /*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
@@ -80,7 +79,7 @@ namespace Banshee.Base
             //mb_disc.Client.Debug = true;
             
             foreach(SimpleTrack mb_track in mb_disc) {
-                AudioCdTrackInfo track = new AudioCdTrackInfo(device_node);
+                AudioCdTrackInfo track = new AudioCdTrackInfo(this);
                 track.Duration = new TimeSpan(mb_track.Length * TimeSpan.TicksPerSecond);
                 track.TrackIndex = mb_track.Index;
                 track.Artist = Catalog.GetString("Unknown Artist");
@@ -214,7 +213,7 @@ namespace Banshee.Base
         
         private void HandleUpdated()
         {
-            Gtk.Application.Invoke(delegate {
+            ThreadAssist.ProxyToMain(delegate {
                 EventHandler handler = Updated;
                 if(handler != null) {
                     handler(this, new EventArgs());
@@ -222,17 +221,6 @@ namespace Banshee.Base
             });
         }
         
-        public AudioCdLookupStatus Status {
-            get {
-                return status;
-            }
-            
-            private set {
-                status = value;
-                HandleUpdated();
-            }
-        }
-        
         [DllImport("libc")]
         private static extern int ioctl(int device, EjectOperation request); 
 
@@ -249,6 +237,17 @@ namespace Banshee.Base
         public bool Eject(bool open)
         {
             try {
+                if(IsRipping) {
+                    LogCore.Instance.PushWarning(Catalog.GetString("Cannot Eject CD"),
+                        Catalog.GetString("The CD cannot be ejected while it is importing. Stop the import first."));
+                    return false;
+                }
+                
+                AudioCdTrackInfo track = PlayerEngineCore.CurrentTrack as AudioCdTrackInfo;
+                if(track != null && track.Device == DeviceNode) {
+                    PlayerEngineCore.Close();
+                }
+            
                 Hal.Device device = new Hal.Device(HalCore.Context, udi);
                 if(device.GetPropertyBool("volume.is_mounted")) {
                     if(!Utilities.UnmountVolume(device_node)) {
@@ -268,46 +267,47 @@ namespace Banshee.Base
             }
         }
         
-        public string Udi { 
-            get { 
-                return udi;
+        public AudioCdLookupStatus Status {
+            get { return status; }
+            
+            private set {
+                status = value;
+                HandleUpdated();
             }
         }
         
+        public string Udi { 
+            get { return udi; }
+        }
+        
         public string DeviceNode { 
-            get { 
-                return device_node;
-            }
+            get { return device_node; }
         }
         
         public string DriveName { 
-            get { 
-                return drive_name;
-            }
+            get { return drive_name; }
         }
         
         public string Title { 
-            get { 
-                return album_title;
-            }
+            get { return album_title; }
         }
         
         public int TrackCount { 
-            get { 
-                return tracks.Length; 
-            }
+            get { return tracks.Length; }
         }
         
         public bool Valid { 
-            get { 
-                return true;
-            }
+            get { return true; }
         }
         
-        public AudioCdTrackInfo [] Tracks { 
-            get { 
-                return tracks; 
-            }
+        public IEnumerable Tracks { 
+            get { return tracks; }
+        }
+        
+        private bool is_ripping = false;
+        public bool IsRipping {
+            get { return is_ripping; }
+            set { is_ripping = value; }
         }
     }
 }
