@@ -1,9 +1,8 @@
-
 /***************************************************************************
  *  DapSource.cs
  *
- *  Copyright (C) 2005 Novell
- *  Written by Aaron Bockover (aaron@aaronbock.net)
+ *  Copyright (C) 2005-2006 Novell, Inc.
+ *  Written by Aaron Bockover <aaron@abock.org>
  ****************************************************************************/
 
 /*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
@@ -71,6 +70,8 @@ namespace Banshee.Sources
         
         public override void AddTrack(TrackInfo track)
         {
+            device.Activate();
+            
             if(track is LibraryTrackInfo) {
                 device.AddTrack(track);
             }
@@ -103,6 +104,7 @@ namespace Banshee.Sources
                     syncing_label.Markup = "<big><b>" + GLib.Markup.EscapeText(
                         Catalog.GetString("Synchronizing your Device, Please Wait...")) + "</b></big>";
                     syncing_box.PackStart(syncing_label, false, false, 0);
+                    syncing_container.ShowAll ();
                 }
                 
                 dap_syncing_image.Pixbuf = device.GetIcon(128);
@@ -126,6 +128,12 @@ namespace Banshee.Sources
             OnViewChanged();
             OnUpdated();
         }
+        
+        public override void Activate()
+        {
+            device.Activate();
+            base.Activate();
+        }
 
         public override int Count {
             get {
