@@ -27,6 +27,7 @@
  */
  
 using System;
+using System.Collections;
 using System.Runtime.InteropServices;
 using Mono.Unix;
 
@@ -202,9 +203,14 @@ namespace Banshee.MediaEngine.Gstreamer
         }
         
         private static string [] source_capabilities = { "file", "http", "cdda" };
-        public override string [] SourceCapabilities {
+        public override IEnumerable SourceCapabilities {
             get { return source_capabilities; }
         }
+                
+        private static string [] decoder_capabilities = { "wma", "asf", "flac" };
+        public override IEnumerable ExplicitDecoderCapabilities {
+            get { return decoder_capabilities; }
+        }
         
         [DllImport("libbanshee")]
         private static extern IntPtr gst_playback_new();
@@ -374,9 +380,14 @@ namespace Banshee.MediaEngine.Gstreamer
         }
         
         private static string [] source_capabilities = { "file", "http", "cdda" };
-        public override string [] SourceCapabilities {
+        public override IEnumerable SourceCapabilities {
             get { return source_capabilities; }
         }
+                
+        private static string [] decoder_capabilities = { "wma", "asf", "flac" };
+        public override IEnumerable ExplicitDecoderCapabilities {
+            get { return decoder_capabilities; }
+        }
         
         [DllImport("libbanshee")]
         private static extern IntPtr gpe_new();
