@@ -27,6 +27,7 @@
  */
 
 using System;
+using System.Collections;
 
 using Helix;
 
@@ -39,24 +40,38 @@ namespace Banshee.MediaEngine.Helix
     {
         private RemotePlayer player;
         private uint timeout_id;
+        private uint ping_id;
         
         public HelixRemotePlayerEngine()
         {
             player = RemotePlayer.Connect();
             player.Stop();
             player.Message += OnRemotePlayerMessage;
+            
+            ping_id = GLib.Timeout.Add(5000, delegate {
+                if(player == null) {
+                    return false;
+                }
+                
+                player.Ping();
+                return true;
+            });
         }
         
         public override void Dispose()
         {
             base.Dispose();
             player.Dispose();
+            player = null;
+            GLib.Source.Remove(ping_id);
         }
                 
         protected override void OpenUri(Uri uri)
         {
-            player.OpenUri(uri.AbsoluteUri);
-            
+            if(!player.OpenUri(uri.AbsoluteUri)) {
+                throw new ApplicationException("Cannot open URI");
+            }
+
             timeout_id = GLib.Timeout.Add(500, delegate {
                 if(CurrentState == PlayerEngineState.Playing) {
                     OnEventChanged(PlayerEngineEvent.Iterate);
@@ -104,12 +119,29 @@ namespace Banshee.MediaEngine.Helix
                             break;
                         case ContentState.Loading:
                         case ContentState.Contacting:
-                            OnEventChanged(PlayerEngineEvent.Buffering);
                             break;
                         default:
                             OnStateChanged(PlayerEngineState.Idle);
                             break;
                     }
+                    break;
+                case MessageType.Buffering:
+                    uint progress = (uint)message["Percent"];
+                    OnEventChanged(PlayerEngineEvent.Buffering, 
+                        null, (double)progress / 100.0);
+                    break;
+                case MessageType.Title:
+                    string title = message["Title"] as string;
+                    if(title == null || title.Trim() == String.Empty) {
+                        break;
+                    }
+                
+                    StreamTag tag = new StreamTag();
+                    tag.Name = CommonTags.Title;
+                    tag.Value = (string)message["Title"];
+                    
+                    OnTagFound(tag);
+                    
                     break;
             }
         }
@@ -139,6 +171,10 @@ namespace Banshee.MediaEngine.Helix
             get { return (uint)player.GetLength() / 1000; }
         }        
         
+        public override bool CanSeek {
+            get { return !player.GetIsLive(); }
+        }
+        
         public override string Id {
             get { return "helix-remote"; }
         }
@@ -148,8 +184,13 @@ namespace Banshee.MediaEngine.Helix
         }
         
         private static string [] source_capabilities = { "file", "http" };
-        public override string [] SourceCapabilities {
+        public override IEnumerable SourceCapabilities {
             get { return source_capabilities; }
         }
+        
+        private static string [] decoder_capabilities = { "m4a", "mp3", "ram", "ra", "rm", "aac", "mp4" };
+        public override IEnumerable ExplicitDecoderCapabilities {
+            get { return decoder_capabilities; }
+        }
     }
 }
