@@ -1,4 +1,4 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
+
 /***************************************************************************
  *  BansheeDbusClient.cs
  *
@@ -40,7 +40,7 @@ using System;
 using DBus;
 using Gtk;
 
-[Interface("org.gnome.Banshee.Player")]
+[Interface("org.gnome.Banshee.Core")]
 public abstract class BansheePlayer
 {       
     public static BansheePlayer FindInstance()
