@@ -385,6 +385,8 @@ namespace Banshee
                 sourceViewDestEntries, 
                 DragAction.Copy | DragAction.Move);
 
+            InterfaceElements.MainContainer = gxml["MainContainer"] as VBox;
+
             // Playlist View
             playlistModel = new PlaylistModel();
             playlistView = new PlaylistView(playlistModel);
@@ -452,7 +454,6 @@ namespace Banshee
             SetTip(previous_button, Catalog.GetString("Play previous song"));
             SetTip(playpause_button, Catalog.GetString("Play/pause current song"));
             SetTip(next_button, Catalog.GetString("Play next song"));
-            SetTip(seek_slider, Catalog.GetString("Current position in song"));
             SetTip(dapDiskUsageBar, Catalog.GetString("Device disk usage"));
             SetTip(sync_dap_button, Catalog.GetString("Synchronize music library to device"));
             SetTip(volumeButton, Catalog.GetString("Adjust volume"));
@@ -867,22 +868,24 @@ namespace Banshee
 
         private void OnPlayerEngineTick()
         {
+            uint stream_length = PlayerEngineCore.Length;
+            uint stream_position = PlayerEngineCore.Position;
+            
             seek_slider.CanSeek = PlayerEngineCore.CanSeek;
-            seek_slider.SeekValue = PlayerEngineCore.Position;
+            seek_slider.Duration = stream_length;
+            seek_slider.SeekValue = stream_position;
             
             if(PlayerEngineCore.CurrentTrack == null) {
                 return;
             }
-            
-            if(PlayerEngineCore.Length > 0 && PlayerEngineCore.CurrentTrack.Duration.TotalSeconds <= 0.0) {
-                PlayerEngineCore.CurrentTrack.Duration = new TimeSpan(PlayerEngineCore.Length * TimeSpan.TicksPerSecond);
+           
+            if(stream_length > 0 && PlayerEngineCore.CurrentTrack.Duration.TotalSeconds != (double)stream_length) {
+                PlayerEngineCore.CurrentTrack.Duration = new TimeSpan(stream_length * TimeSpan.TicksPerSecond);
                 PlayerEngineCore.CurrentTrack.Save();
                 playlistView.QueueDraw();
-                seek_slider.Duration = PlayerEngineCore.CurrentTrack.Duration.TotalSeconds;
             }
             
-            if(PlayerEngineCore.Length > 0 && PlayerEngineCore.Position > PlayerEngineCore.Length / 2
-                && !incrementedCurrentSongPlayCount) {
+            if(stream_length > 0 && stream_position > stream_length / 2 && !incrementedCurrentSongPlayCount) {
                 PlayerEngineCore.CurrentTrack.IncrementPlayCount();
                 incrementedCurrentSongPlayCount = true;
                 playlistView.QueueDraw();
@@ -1320,13 +1323,15 @@ namespace Banshee
                 return;
             }
             
-            foreach(TrackInfo track in SourceManager.ActiveSource.Tracks) {
-                try {
-                    if(DoesTrackMatchSearch(track)) {
-                        playlistModel.AddTrack(track);
+            lock(SourceManager.ActiveSource.TracksMutex) {
+                foreach(TrackInfo track in SourceManager.ActiveSource.Tracks) {
+                    try {
+                        if(DoesTrackMatchSearch(track)) {
+                            playlistModel.AddTrack(track);
+                        }
+                    } catch(Exception) {
+                        continue;
                     }
-                } catch(Exception) {
-                    continue;
                 }
             }
             
@@ -1814,7 +1819,7 @@ namespace Banshee
             for(i = 0; i < iters.Length; i++) {
                 TrackInfo track = playlistModel.IterTrackInfo(iters[i]);
                 SourceManager.ActiveSource.RemoveTrack(track);
-                playlistModel.Remove(ref iters[i]);
+                playlistModel.RemoveTrack(ref iters[i], track);
                 
                 if(deleteFromFileSystem) {
                     DeleteSong(track);
@@ -1906,8 +1911,22 @@ namespace Banshee
             if(playlistView.Selection.CountSelectedRows() <= 0) {
                 return;
             }
-        
-            BurnCore burnCore = new BurnCore(BurnCore.DiskType.Audio);
+            
+            string drive_id = null;
+            try {
+                drive_id = (string)Globals.Configuration.Get(GConfKeys.CDBurnerId);
+            } catch {
+            }
+            
+            BurnCore.DiskType disk_type = BurnCore.DiskType.Audio;
+            
+            try {
+                string key = GConfKeys.CDBurnerRoot + drive_id + "/DiskFormat";
+                disk_type = (BurnCore.DiskType)Globals.Configuration.Get(key);
+            } catch {
+            }
+            
+            BurnCore burnCore = new BurnCore(disk_type);
         
             foreach(TreePath path in playlistView.Selection.GetSelectedRows()) {
                 burnCore.AddTrack(playlistModel.PathTrackInfo(path));
